@@ -12,8 +12,6 @@ import signal
 import string
 import sys
 from ruamel.yaml import YAML
-import aiofiles
-import aiostream
 import string
 import random
 import copy
